@@ -71,7 +71,7 @@ public:
 
 class KnowitPreferences : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 private:
    TQCheckBox *docked, *reopen, *horizontalSplit,  *multipleInstances, *backup;
